@@ -19,7 +19,7 @@ def image_to_tensor(image: Image) -> np.ndarray:
     """
     image = image.resize((112, 112), Image.BICUBIC)
     image = image.convert('RGB')
-    tensor = np.asarray(image, dtype=np.float32)
+    tensor = np.asarray(image).astype(np.float32)
     tensor = (tensor - 127.5) * 0.0078125
     assert tensor.shape == (112, 112, 3)
     return tensor
