@@ -1,8 +1,10 @@
 """init."""
 from .preprocess import image_to_tensor
+from .calibration import save_calibration_tensor
 from .postprocess import get_postprocessed_output
 
 __all__ = [
     'image_to_tensor',
+    'save_calibration_tensor',
     'get_postprocessed_output',
 ]
