@@ -10,7 +10,8 @@ def get_postprocessed_predictions(predictions: Dict[str, np.ndarray], image_shap
                                   fmap_size: int = 19) -> tuple:
     """Convert output convolution tensor to final scores, boxes, classes."""
     anchors = np.array(ANCHORS)
-    predictions = predictions['conv2d_9/BiasAdd:0']
+    out_name = list(predictions.keys())[0]
+    predictions = predictions[out_name]
     yolo_outputs = yolo_head(predictions, anchors, fmap_size, len(CLASS_NAMES))
 
     out_scores, out_boxes, out_classes = yolo_eval(yolo_outputs, image_shape,
