@@ -94,7 +94,7 @@ def freeze_graph_from_ckpt(
         ckpt_dir: str,
         output_node_names: str,
         to_dump: bool = False,
-        tensorboad_event: bool = False) -> tf.Graph:
+        tensorboard_event: bool = False) -> tf.Graph:
     """
     Extract the checkpoint files defined by the output nodes and convert all its variables into constant.
 
@@ -106,7 +106,7 @@ def freeze_graph_from_ckpt(
         a string, containing all the output node's names, comma separated
     to_dump
         boolean flag indicates save graph to the filesystem or not
-    tensorboad_event
+    tensorboard_event
         Set it true in case of lack of information about node's names to get tensorboard event
     Returns
     -------
@@ -121,7 +121,7 @@ def freeze_graph_from_ckpt(
         print("You need to supply the name of a node to --output_node_names.")
         return -1
 
-    # We retrieve our checkpoint fullpath
+    # We retrieve our checkpoint full path
     checkpoint = tf_v1.train.get_checkpoint_state(ckpt_dir)
     input_checkpoint = checkpoint.model_checkpoint_path
 
@@ -132,7 +132,7 @@ def freeze_graph_from_ckpt(
     with tf_v1.Session(graph=tf_v1.Graph()) as sess:
         # We import the meta graph in the current default Graph
         saver = tf_v1.train.import_meta_graph(input_checkpoint + '.meta', clear_devices=clear_devices)
-        if tensorboad_event:
+        if tensorboard_event:
             tf_v1.summary.FileWriter(ckpt_dir, sess.graph)  # view the nodes of a meta graph
 
         # We restore the weights
@@ -142,10 +142,10 @@ def freeze_graph_from_ckpt(
         frozen_graph = tf_v1.graph_util.convert_variables_to_constants(
             sess,  # The session is used to retrieve the weights
             tf_v1.get_default_graph().as_graph_def(),  # The graph_def is used to retrieve the nodes
-            output_node_names.split(",")  # The output node names are used to select the usefull nodes
+            output_node_names.split(",")  # The output node names are used to select the useful nodes
         )
         if to_dump:
-            # We precise the file fullname of our freezed graph
+            # We precise the file fullname of our frozen graph
             absolute_model_dir = "/".join(input_checkpoint.split('/')[:-1])
             output_graph = absolute_model_dir + "/frozen_graph.pb"
             # Finally we serialize and dump the output graph to the filesystem
@@ -156,6 +156,41 @@ def freeze_graph_from_ckpt(
     return frozen_graph
 
 
+def freeze_graph_from_saved_model(model_dir: str, save_dir: str = ".", graph_name: str = 'frozen_graph.pb',
+                                  as_text: bool = False, concrete_func: tf.function = None):
+    """
+    Freeze the graph from TensorFlow saved_model and variables.
+
+    Parameters
+    ----------
+    model_dir
+        Path to the model directory containing saved_model and variables
+    save_dir
+        Path to the save dir for the frozen graph
+    graph_name
+        Result name of the frozen_graph
+    as_text
+        Bool variable if to save as text or not
+    concrete_func
+        Concrete function might be explicitly given to freeze constants
+    Returns
+    -------
+
+    """
+    model = tf.saved_model.load(model_dir, tags=[['serve']])
+    if not concrete_func:
+        try:
+            concrete_func = model.signatures['serving_default']
+        except KeyError:
+            raise KeyError('Need to provide an explicit ConcreteFunction to freeze coefficients.')
+    frozen_func = convert_variables_to_constants_v2(concrete_func)
+
+    tf.io.write_graph(graph_or_graph_def=frozen_func.graph,
+                      logdir=save_dir,
+                      name=graph_name,
+                      as_text=as_text)
+
+
 def wrap_frozen_graph(graph_def: tf_v1.GraphDef, inputs: List[str], outputs: List[str]):
     """
     Return a function used to run the graph.
@@ -202,18 +237,18 @@ def optimize_frozen_graph_def(frozen_graph_def, input_node_names: List[str], out
     return output_graph_def
 
 
-def freeze_keras_model(model, save_dir: str) -> None:
+def freeze_keras_model(model, save_dir: str, concrete_func: tf.function = None) -> None:
     """Freeze keras model and export it to protobuf file."""
     full_model = tf.function(lambda x: model(x))
     inputs: list = []
-    for model_input in model.inputs:
-        inputs.append(tf.TensorSpec(model_input.shape, model_input.dtype, name=model_input.name[:-2]))
-    full_model = full_model.get_concrete_function(tuple(inputs))
-    frozen_func = convert_variables_to_constants_v2(full_model)
+    if not concrete_func:
+        for model_input in model.inputs:
+            inputs.append(tf.TensorSpec(model_input.shape, model_input.dtype, name=model_input.name))
+        concrete_function = full_model.get_concrete_function(tuple(inputs))
+        frozen_func = convert_variables_to_constants_v2(concrete_function)
+    else:
+        frozen_func = convert_variables_to_constants_v2(concrete_func)
     graph_def = frozen_func.graph.as_graph_def()
-    for i, _ in enumerate(graph_def.node):
-        if "Identity" in graph_def.node[i].name:
-            del graph_def.node[i]
     tf.io.write_graph(graph_or_graph_def=graph_def,
                       logdir=save_dir,
                       name=f"{model.name}.pb",
